GetDeviceLanguageRes class

第三层:获取设备语言应答

Constructors

GetDeviceLanguageRes({required DeviceLanguage language})
构造函数
const

Properties

hashCode int
The hash code for this object.
no setterinherited
language DeviceLanguage
语言枚举
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromBytes(List<int> bytes) GetDeviceLanguageRes
从第三层字节数组解析设备语言应答