SetSpeedReq class

第三层:速度控制请求

Constructors

SetSpeedReq({required double linearVelocity, required double angularVelocity})
构造函数
const

Properties

angularVelocity double
角速度(r/s),以 float32 BE 编码
final
hashCode int
The hash code for this object.
no setterinherited
linearVelocity double
线速度(m/s),以 float32 BE 编码
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() List<int>
编码第三层请求负载(float32 BE: 线速度 + 角速度)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited