SetSpeedAck class
第三层:速度控制应答(Ack)
说明:该应答不携带第三层载荷,仅通过一层 Cmd=AckOK 表示成功。
Constructors
- SetSpeedAck()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromBytes(
List< int> bytes) → SetSpeedAck - 从第三层字节解析 Ack